import React, { Fragment, useState, useEffect } from "react";
import Container from "../../components/Container";
import PageTitle from "../../components/PageTitle";
import CartSummery from "../../components/Cart/CartSummery";
import CartAddress from "../../components/Cart/CartAddress";
import ProductDivision from "../../components/Cart/ProductDivision";
import EmptyCart from "../../components/common/EmptyCart";
import {
  useCartDataQuery,
  useCheckoutPageQuery,
  useLazyCartDataQuery,
} from "../../app/features/cart/apiSlice";
import Modal from "../../components/Modal/Modal";
import { RadioGroup } from "@headlessui/react";
import {
  useCashOnDeliveryMutation,
  usePayWithAgreementMutation,
} from "../../app/features/order/apiSlice";
import { useLazyUserOrderListQuery } from "../../app/features/userDashboard/apiSlice";
import LoadingCom from "../../components/common/loadingCom";
import useLanguage from "../../hooks/useLanguage";
import YandexMap from "../../components/helpers/YandexMap";
import { useRouter } from "next/router";

// const CashOnDelivery = () => {
//   const language = useLanguage();
//   return (
//     <div className="w-[170px] h-[32px] relative justify-center items-center">
//       <span className=" font-bold text-xl text-primary-200 notranslate">
//         {language["Cash On Delivery"]}
//       </span>
//     </div>
//   );
// };

// const plans = [
//   {
//     icon: <CashOnDelivery />,
//     value: "cashOnDelivery",
//   },
// ];

function Cart() {
  const { data, isFetching } = useCartDataQuery();
  const router = useRouter();
  const [updateCartData] = useLazyCartDataQuery();
  const [updateOrderList] = useLazyUserOrderListQuery();
  const { data: checkoutPageData } = useCheckoutPageQuery();
  const [isCheckout, setIsCheckout] = useState(false);
  const [isMap, setIsMap] = useState(false);
  const [paymentOption, setPaymentOption] = useState();
  useEffect(() => {
    if (checkoutPageData) {
      if (checkoutPageData.agreementPayment) {
        setPaymentOption(() => ({
          ...checkoutPageData.agreementPayment,
          active: 1,
        }));
      }
    }
  }, [checkoutPageData]);
  const [deliveryOption, setDeliveryOption] = useState("delivery");
  const [deliveryAddress, setDeliveryAddress] = useState();
  const [deliveryDate, setDeliveryDate] = useState(new Date());
  const [payWithAgreement] = usePayWithAgreementMutation();

  const [cashOnDelivery] = useCashOnDeliveryMutation();
  const language = useLanguage();
  return (
    <>
      <div>
        <PageTitle title={language["Your Cart"]} pageName={language["Cart"]} />
        <section className="lg:py-20 py-4 bg-[#FDF9FF]">
          <Container>
            {data?.cartProducts?.length > 0 ? (
              <div className="grid lg:grid-cols-12 lg:gap-7 gap-4 ">
                <div className="lg:col-span-8 flex flex-col gap-10 ">
                  <CartAddress
                    deliveryType={deliveryOption}
                    setDeliveryType={setDeliveryOption}
                    address={deliveryAddress}
                    setAddress={setDeliveryAddress}
                    date={deliveryDate}
                    setDate={setDeliveryDate}
                    mapHandler={() => setIsMap(!isMap)}
                  />
                  {data?.cartProducts.length > 0 &&
                    data?.cartProducts?.map(
                      (cartItem) =>
                        cartItem.products.length > 0 && (
                          <ProductDivision key={cartItem.id} shops={cartItem} />
                        )
                    )}
                </div>

                <div className="lg:col-span-4 space-y-7">
                  <CartSummery
                    products={data.cartProducts}
                    checkout={setIsCheckout}
                    disabledCheckout={false}
                  />
                </div>
              </div>
            ) : isFetching ? (
              <LoadingCom />
            ) : (
              <EmptyCart />
            )}
          </Container>
        </section>
      </div>
      <Modal isOpen={isMap} onClose={() => setIsMap(false)}>
        <div className="bg-white relative rounded-2xl p-10 w-full">
          <button
            className="absolute top-4 right-4"
            onClick={() => setIsMap(false)}
          >
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="36"
              height="36"
              viewBox="0 0 36 36"
              fill="none"
            >
              <path
                d="M22.2426 22.2426L13.7574 13.7574M13.7574 22.2426L22.2426 13.7574M18 33C26.2843 33 33 26.2843 33 18C33 9.71573 26.2843 3 18 3C9.71573 3 3 9.71573 3 18C3 26.2843 9.71573 33 18 33Z"
                stroke="#EB5757"
                strokeWidth="1.5"
                strokeLinecap="round"
              />
            </svg>
          </button>

          <div className="flex flex-col items-center justify-center gap-10 ">
            <h3 className="text-3xl font-bold text-dark-300 text-center notranslate">
              Choose Your Location
            </h3>
            <div className="xl:w-[800px] md:w-[500px] w-[280px]">
              <YandexMap
                toggleModalHandler={() => setIsMap(!setIsMap)}
                selectAddressHandler={setDeliveryAddress}
              />
            </div>
          </div>
        </div>
      </Modal>
      <Modal isOpen={isCheckout} onClose={() => setIsCheckout(false)}>
        <div className="bg-white relative rounded-2xl p-10 w-full">
          <button
            className="absolute top-4 right-4"
            onClick={() => setIsCheckout(false)}
          >
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="36"
              height="36"
              viewBox="0 0 36 36"
              fill="none"
            >
              <path
                d="M22.2426 22.2426L13.7574 13.7574M13.7574 22.2426L22.2426 13.7574M18 33C26.2843 33 33 26.2843 33 18C33 9.71573 26.2843 3 18 3C9.71573 3 3 9.71573 3 18C3 26.2843 9.71573 33 18 33Z"
                stroke="#EB5757"
                strokeWidth="1.5"
                strokeLinecap="round"
              />
            </svg>
          </button>
          <div className="flex flex-col items-center justify-center gap-5 ">
            <h3 className="text-3xl font-bold text-dark-300 text-center notranslate">
              {language["Select a payment method"]}.
            </h3>
            <div className="max-w-[800px] mt-5">
              <RadioGroup
                value={paymentOption}
                onChange={setPaymentOption}
                className="flex gap-5 flex-wrap justify-center "
              >
                {/* {plans.map((plan) => (
                  <RadioGroup.Option key={plan} value={plan} as={Fragment}>
                    {({ active }) => (
                      <li
                        className={`${
                          active
                            ? " text-white border-primary-200"
                            : "bg-white text-black"
                        } py-4 px-5 border border-primary-100 list-none rounded`}
                      >
                        {plan.icon}
                      </li>
                    )}
                  </RadioGroup.Option>
                ))} */}
                {checkoutPageData?.agreementPayment?.status && (
                  <RadioGroup.Option
                    value={checkoutPageData?.agreementPayment}
                    as={Fragment}
                  >
                    {({ active }) => (
                      <li
                        className={`${
                          active || paymentOption.active === 1
                            ? " text-white border-primary-200"
                            : "bg-white text-black"
                        }  border border-primary-100 list-none rounded`}
                      >
                        <img
                          src={
                            process.env.BASE_URL +
                            checkoutPageData?.agreementPayment?.image
                          }
                          alt=""
                          className="w-[170px] h-[56px] object-contain"
                        />
                      </li>
                    )}
                  </RadioGroup.Option>
                )}
              </RadioGroup>
            </div>
            {paymentOption && (
              <div
                className=""
                dangerouslySetInnerHTML={{ __html: paymentOption?.instraction }}
              ></div>
            )}
            <button
              onClick={() => {
                if (paymentOption.value === "cashOnDelivery") {
                  cashOnDelivery({
                    orderType: deliveryOption,
                    location: deliveryAddress,
                    date: deliveryDate,
                    updateCartData,
                    updateOrderList,
                    closeModal: setIsCheckout,
                  });
                } else if (paymentOption.name === "agreement") {
                  payWithAgreement({
                    orderType: deliveryOption,
                    location: deliveryAddress,
                    date: deliveryDate,
                    updateCartData,
                    updateOrderList,
                    closeModal: setIsCheckout,
                    redirect: () =>
                      router.push(
                        `/become-a-company?order_type=${deliveryOption}&&received_location=${deliveryAddress}&&received_date=${deliveryDate}`
                      ),
                  });
                }
              }}
              className="py-3.5 w-full px-8 text-center font-medium text-white rounded transition bg-primary-200 hover:bg-primary-200/80 mt-5"
              disabled={!paymentOption}
            >
              Check Out
            </button>
          </div>
        </div>
      </Modal>
    </>
  );
}

export default Cart;
